Peter Reilly wrote:

Kev Jackson wrote:

Just some small changes that reduce the whining my IDE does :)


Checkstyle whines about missing description for paramters.

Sorry about that, here's an update that hopefully fixes those.
Index: Rmic.java
===================================================================
RCS file: /home/cvspublic/ant/src/main/org/apache/tools/ant/taskdefs/Rmic.java,v
retrieving revision 1.58
diff -u -r1.58 Rmic.java
--- Rmic.java   22 Nov 2004 09:23:28 -0000      1.58
+++ Rmic.java   3 Dec 2004 11:32:12 -0000
@@ -26,7 +26,6 @@
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.taskdefs.rmic.RmicAdapter;
 import org.apache.tools.ant.taskdefs.rmic.RmicAdapterFactory;
-import org.apache.tools.ant.taskdefs.rmic.KaffeRmic;
 import org.apache.tools.ant.types.FilterSetCollection;
 import org.apache.tools.ant.types.Path;
 import org.apache.tools.ant.types.Reference;
@@ -88,14 +87,14 @@
     private File sourceBase;
     private String stubVersion;
     private Path compileClasspath;
-    private Path extdirs;
+    private Path extDirs;
     private boolean verify = false;
     private boolean filtering = false;
 
     private boolean iiop = false;
-    private String  iiopopts;
+    private String  iiopOpts;
     private boolean idl  = false;
-    private String  idlopts;
+    private String  idlOpts;
     private boolean debug  = false;
     private boolean includeAntRuntime = true;
     private boolean includeJavaRuntime = false;
@@ -121,6 +120,7 @@
 
     /**
      * Sets the location to store the compiled files; required
+     * @param base the location to store the compiled files
      */
     public void setBase(File base) {
         this.baseDir = base;
@@ -128,6 +128,7 @@
 
     /**
      * Gets the base directory to output generated class.
+     * @return the location of the compiled files
      */
 
     public File getBase() {
@@ -137,6 +138,7 @@
     /**
      * Sets the class to run <code>rmic</code> against;
      * optional
+     * @param classname the name of the class for rmic to create code for
      */
     public void setClassname(String classname) {
         this.classname = classname;
@@ -144,6 +146,7 @@
 
     /**
      * Gets the class name to compile.
+     * @return the name of the class to compile
      */
     public String getClassname() {
         return classname;
@@ -151,6 +154,7 @@
 
     /**
      * optional directory to save generated source files to.
+     * @param sourceBase the directory to save source files to.
      */
     public void setSourceBase(File sourceBase) {
         this.sourceBase = sourceBase;
@@ -158,6 +162,7 @@
 
     /**
      * Gets the source dirs to find the source java files.
+     * @return sourceBase the directory containing the source files.
      */
     public File getSourceBase() {
         return sourceBase;
@@ -166,30 +171,40 @@
     /**
      * Specify the JDK version for the generated stub code.
      * Specify &quot;1.1&quot; to pass the &quot;-v1.1&quot; option to 
rmic.</td>
+     * @param stubVersion the JDK version
      */
     public void setStubVersion(String stubVersion) {
         this.stubVersion = stubVersion;
     }
 
+    /**
+     * Gets the JDK version for the generated stub code.  
+     * @return stubVersion
+     */
     public String getStubVersion() {
         return stubVersion;
     }
 
     /**
-     * indicates whether token filtering should take place;
-     * optional, default=false
+     * Sets token filtering [optional], default=false
+     * @param filter turn on token filtering
      */
     public void setFiltering(boolean filter) {
-        filtering = filter;
+        this.filtering = filter;
     }
 
+    /**
+     * Gets whether token filtering is set 
+     * @return filtering
+     */
     public boolean getFiltering() {
         return filtering;
     }
 
     /**
-     * generate debug info (passes -g to rmic);
+     * Generate debug info (passes -g to rmic);
      * optional, defaults to false
+     * @param debug turn on debug info
      */
     public void setDebug(boolean debug) {
         this.debug = debug;
@@ -197,6 +212,7 @@
 
     /**
      * Gets the debug flag.
+     * @return debug
      */
     public boolean getDebug() {
         return debug;
@@ -204,6 +220,7 @@
 
     /**
      * Set the classpath to be used for this compilation.
+     * @param classpath the classpath used for this compilation
      */
     public void setClasspath(Path classpath) {
         if (compileClasspath == null) {
@@ -215,6 +232,7 @@
 
     /**
      * Creates a nested classpath element.
+     * @return classpath
      */
     public Path createClasspath() {
         if (compileClasspath == null) {
@@ -226,9 +244,10 @@
     /**
      * Adds to the classpath a reference to
      * a &lt;path&gt; defined elsewhere.
+     * @param pathRef the reference to add to the classpath
      */
-    public void setClasspathRef(Reference r) {
-        createClasspath().setRefid(r);
+    public void setClasspathRef(Reference pathRef) {
+        createClasspath().setRefid(pathRef);
     }
 
     /**
@@ -242,14 +261,18 @@
      * Flag to enable verification so that the classes
      * found by the directory match are
      * checked to see if they implement java.rmi.Remote.
-     * Optional; his defaults to false if not set.
+     * optional; This defaults to false if not set.
+     * @param verify turn on verification for classes
      */
 
     public void setVerify(boolean verify) {
         this.verify = verify;
     }
 
-    /** Get verify flag. */
+    /** 
+     * Get verify flag. 
+     * @return verify 
+     */
     public boolean getVerify() {
         return verify;
     }
@@ -258,6 +281,7 @@
      * Indicates that IIOP compatible stubs should
      * be generated; optional, defaults to false
      * if not set.
+     * @param iiop generate IIOP compatible stubs 
      */
     public void setIiop(boolean iiop) {
         this.iiop = iiop;
@@ -265,6 +289,7 @@
 
     /**
      * Gets iiop flags.
+     * @return iiop
      */
     public boolean getIiop() {
         return iiop;
@@ -272,22 +297,25 @@
 
     /**
      * Set additional arguments for iiop
+     * @param iiopOpts additional arguments for iiop
      */
-    public void setIiopopts(String iiopopts) {
-        this.iiopopts = iiopopts;
+    public void setIIOPOpts(String iiopOpts) {
+        this.iiopOpts = iiopOpts;
     }
 
     /**
      * Gets additional arguments for iiop.
+     * @return iiopOpts
      */
-    public String getIiopopts() {
-        return iiopopts;
+    public String getIIOPOpts() {
+        return iiopOpts;
     }
 
     /**
      * Indicates that IDL output should be
      * generated.  This defaults to false
      * if not set.
+     * @param idl generate IDL output
      */
     public void setIdl(boolean idl) {
         this.idl = idl;
@@ -301,17 +329,18 @@
     }
 
     /**
      * pass additional arguments for idl compile
      */
-    public void setIdlopts(String idlopts) {
-        this.idlopts = idlopts;
+    public void setIDLopts(String idlOpts) {
+        this.idlOpts = idlOpts;
     }
 
     /**
      * Gets additional arguments for idl compile.
      */
-    public String getIdlopts() {
-        return idlopts;
+    public String getIDLOpts() {
+        return idlOpts;
     }
 
     /**
@@ -326,15 +355,15 @@
      * classpath.
      * Optional; default is <code>true</code>.
      */
-    public void setIncludeantruntime(boolean include) {
-        includeAntRuntime = include;
+    public void setIncludeAntRuntime(boolean include) {
+        this.includeAntRuntime = include;
     }
 
     /**
      * Gets whether or not the ant classpath is to be included in the
      * task's classpath.
      */
-    public boolean getIncludeantruntime() {
+    public boolean getIncludeAntRuntime() {
         return includeAntRuntime;
     }
 
@@ -344,7 +373,7 @@
      * libraries from the executing VM; optional,
      * defaults to false
      */
-    public void setIncludejavaruntime(boolean include) {
+    public void setIncludeJavaRuntime(boolean include) {
         includeJavaRuntime = include;
     }
 
@@ -352,7 +381,7 @@
      * Gets whether or not the java runtime should be included in this
      * task's classpath.
      */
-    public boolean getIncludejavaruntime() {
+    public boolean getIncludeJavaRuntime() {
         return includeJavaRuntime;
     }
 
@@ -360,30 +389,30 @@
      * Sets the extension directories that will be used during the
      * compilation; optional.
      */
-    public void setExtdirs(Path extdirs) {
-        if (this.extdirs == null) {
-            this.extdirs = extdirs;
+    public void setExtDirs(Path extDirs) {
+        if (this.extDirs == null) {
+            this.extDirs = extDirs;
         } else {
-            this.extdirs.append(extdirs);
+            this.extDirs.append(extDirs);
         }
     }
 
     /**
      * Maybe creates a nested extdirs element.
      */
     public Path createExtdirs() {
-        if (extdirs == null) {
-            extdirs = new Path(getProject());
+        if (extDirs == null) {
+            extDirs = new Path(getProject());
         }
-        return extdirs.createPath();
+        return extDirs.createPath();
     }
 
     /**
      * Gets the extension directories that will be used during the
      * compilation.
      */
-    public Path getExtdirs() {
-        return extdirs;
+    public Path getExtDirs() {
+        return extDirs;
     }
 
     public Vector getCompileList() {
@@ -435,6 +464,8 @@
     /**
      * execute by creating an instance of an implementation
      * class and getting to do the work
+     * @throws org.apache.tools.ant.BuildException 
+     * if there's a problem with baseDir or RMIC
      */
     public void execute() throws BuildException {
         if (baseDir == null) {
@@ -575,7 +606,7 @@
             log("will leave uptodate test to rmic implementation in idl mode.",
                 Project.MSG_VERBOSE);
         } else if (iiop
-                   && iiopopts != null && iiopopts.indexOf("-always") > -1) {
+                   && iiopOpts != null && iiopOpts.indexOf("-always") > -1) {
             log("no uptodate test as -always option has been specified",
                 Project.MSG_VERBOSE);
         } else {

---------------------------------------------------------------------
@@ -301,17 +329,18 @@
 
     /**
-     * pass additional arguments for idl compile
+     * pass additional arguments for IDL compile
+     * @param idlOpts additional IDL arguments
      */
@@ -360,30 +389,30 @@
 
     /**
-     * Maybe creates a nested extdirs element.
+     * Maybe creates a nested extDirs element.
      */
     public Path createExtdirs() {
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]

Reply via email to